@@ -2,8 +2,8 @@
 #
 # Copyright (C) Zenoss, Inc. 2013, all rights reserved.
 #
-# This content is made available according to terms specified in
-# License.zenoss under the directory where your Zenoss product is installed.
+# This content is made available according to terms specified in the LICENSE
+# file at the top-level directory of this package.
 #
 ##############################################################################
 
@@ -14,8 +14,8 @@ from .enumerate import create_winrm_client
 class WinrmCollectClient(object):
 
     @defer.inlineCallbacks
-    def do_collect(self, hostname, username, password, wqls):
-        client = create_winrm_client(hostname, username, password)
+    def do_collect(self, hostname, auth_type, username, password, wqls):
+        client = create_winrm_client(hostname, auth_type, username, password)
         items = {}
         for wql in wqls:
             items[wql] = yield client.enumerate(wql)
@@ -26,6 +26,7 @@ class WinrmCollectClient(object):
 
 if __name__ == '__main__':
     from pprint import pprint
+    from getpass import getpass
     import logging
     from twisted.internet import reactor
     logging.basicConfig()
@@ -34,7 +35,7 @@ if __name__ == '__main__':
     @defer.inlineCallbacks
     def do_example_collect():
         items = yield winrm.do_collect(
-            "gilroy", "Administrator", "Z3n0ss",
+            "gilroy", "basic", "Administrator", getpass(),
             ['Select Caption, DeviceID, Name From Win32_Processor',
              'select Name, Label, Capacity from Win32_Volume'])
         pprint(items)
